@@ -1,4 +1,4 @@
-;;; pces-e20.el --- pces submodule for Emacs 20
+;;; pces-e20.el --- pces submodule for Emacs 20  -*- lexical-binding: t -*-
 
 ;; Copyright (C) 1998,1999 Free Software Foundation, Inc.
 
@@ -26,7 +26,7 @@
 
 (require 'pces-20)
 
-(defsubst-maybe find-coding-system (obj)
+(defsubst find-coding-system (obj)
   "Return OBJ if it is a coding-system."
   (if (coding-system-p obj)
       obj))
